User Guide
==========

This section contains guides and documents about some aspects of IGUA.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   Installing <installing>
   Running IGUA <running>
   Scripting IGUA <scripting>


.. toctree::
   :maxdepth: 1
   :caption: Resources

   Contribution Guide <contributing>
   Changelog <changes>
   Copyright Notice <copyright>
